@@ -4,6 +4,7 @@ lsfiles._indexing
 """
 from __future__ import annotations
 
+import re as _re
 import typing as _t
 from pathlib import Path as _Path
 
@@ -31,15 +32,6 @@ class LSFiles(_MutableSequence):
         """
         self._exclude.extend(exclusions)
 
-    def extend(self, values: _t.Iterable[_Path]) -> None:
-        """Like extend for a regular list but cannot duplicate.
-
-        :param values: Method expects an iterable of ``pathlib.Path``
-            objects.
-        """
-        super().extend(values)
-        self._list = list(set(self))
-
     def populate(self) -> None:
         """Populate object with index of versioned Python files."""
         _git.ls_files(capture=True)
@@ -53,6 +45,18 @@ class LSFiles(_MutableSequence):
             and p.name.endswith(".py")
         )
 
+    def populate_regex(self, exclude: str | None = None) -> None:
+        """Populate object with index of versioned Python files.
+
+        :param exclude: Regex of files to exclude.
+        """
+        _git.ls_files(capture=True)
+        for path in _git.stdout():
+            if path.endswith(".py") and (
+                not exclude or _re.match(exclude, path) is None
+            ):
+                self.append(_Path.cwd() / path)
+
     def reduce(self) -> _t.List[_Path]:
         """Get all relevant python files starting from project root.
 
